:mod:`database` -- Database level operations
--------------------------------------------

.. automodule:: pymongolab.database
    :synopsis: Database level operations
    :members:
    :undoc-members:
    :show-inheritance:
